@@ -91,6 +91,8 @@ class Experiment:
         self.executor = executor
         self.output_file = '%s_%s_%s' %(name, self.executor.hostnames[0], int(time.time()))
 
+        os.makedirs('/tmp/bin/', exist_ok=True)
+        
         self.monitors = monitors
         for monitor in monitors:
             monitor.build(self.executor)
@@ -102,13 +104,13 @@ class Experiment:
         self.bench_suites = benchmarks
         self.build_benchs()
 
+        self.executor.sync('/tmp/bin')
+        
     def build_benchs(self):
         'Builds all the benchmarks'
-        os.makedirs('/tmp/bin/', exist_ok=True)
         for bench_suite in self.bench_suites:
             tmp_params = bench_suite.build(self.executor)
             self.params.update(tmp_params)
-        self.executor.sync('/tmp/bin')
 
     def start_monitors(self):
         'Starts all the monitors'
@@ -150,26 +152,18 @@ class Experiment:
             if bench in bench_suite.names:
                 return bench_suite.run(bench, param, self.executor)
 
-    def do_watermark(self):
-        print('Watermark 30s')
-        mark = 'cat /dev/zero > /dev/null & pid=$!; sleep 5; kill -9 ${pid}'
-        for _ in range(3):
-            time.sleep(3.3)
-            self.executor.cores(mark)
-        time.sleep(5)
-            
     def print_header(self):
         'Prints the initial header in the experimental output file'
         if os.path.exists(self.output_file):
             return
-        res = 'hostname fullname nproc duration startTime endTime '
+        res = ['hostname','fullname','nproc','duration', 'startTime', 'endTime']
         for leverage in self.hw_modes:
-            res += ' '.join(leverage.get_labels())
-        res += ' hostlist\n'
+            res.extend(leverage.get_labels())
+        res.append('hostlist')
         with open(self.output_file, 'w') as output_file:
-            output_file.write(res)
+            output_file.write(' '.join(res)+'\n')
 
-    def monitor_bench(self, bench, param, watermark=False):
+    def monitor_bench(self, bench, param):
         'Runs and monitor the benchmark and then save the results'
         output_time = ''
         self.print_header()
@@ -181,11 +175,7 @@ class Experiment:
 
             beg_time = int(time.time())
             self.start_monitors()
-            if watermark:
-                self.do_watermark()
             output_time, benchname = self.run_bench(bench, param)
-            if watermark:
-                self.do_watermark()
             self.stop_monitors()
             end_time = int(time.time())
 
@@ -204,7 +194,7 @@ class Experiment:
                                    self.executor.hostnames[0],
                                    benchname, beg_time)
 
-def run_experiment(name, benchmarks, leverages=[], monitors=[], sweep=False, times=1, watermark=False):
+def run_experiment(name, benchmarks, leverages=[], monitors=[], sweep=False, times=1):
     """Typical experiment"""
     executor = Executor()
 
@@ -218,5 +208,5 @@ def run_experiment(name, benchmarks, leverages=[], monitors=[], sweep=False, tim
                     param = param()
                 for actions in expe.get_hw_actions():
                     expe.start_actions(actions)
-                    pattern = expe.monitor_bench(bench, param, watermark=watermark)
+                    pattern = expe.monitor_bench(bench, param)
                     expe.stop_actions(actions, pattern)
