@@ -37,7 +37,7 @@ class Power:
         os.makedirs(filename_power, exist_ok=True)
         target =  '%s/%s_%s_%s' % (filename_power, self.executor.hostnames[0], benchname, beg_time)
 
-        request = 'https://api.grid5000.fr/sid/sites/%s/metrics?metrics=wattmetre_power_watt&start_time=%s&end_time=%s&nodes=%s' % (self.site, self.start_time, self.end_time, self.hostnames)
+        request = 'https://api.grid5000.fr/stable/sites/%s/metrics?metrics=wattmetre_power_watt&start_time=%s&end_time=%s&nodes=%s' % (self.site, self.start_time, self.end_time, self.hostnames)
 
         delta = int(time.time())-self.end_time
         if delta < 6:
@@ -55,9 +55,9 @@ class Power:
         for elements in raws:
             device_id = elements['device_id']
             try:
-                timestamps[device_id].append(int(datetime.datetime.strptime(elements['timestamp'], "%Y-%m-%dT%H:%M:%S%z").timestamp()))
+                timestamps[device_id].append(datetime.datetime.strptime(elements['timestamp'], "%Y-%m-%dT%H:%M:%S%z").timestamp())
             except:
-                timestamps[device_id].append(int(datetime.datetime.strptime(elements['timestamp'], "%Y-%m-%dT%H:%M:%S.%f%z").timestamp()))
+                timestamps[device_id].append(datetime.datetime.strptime(elements['timestamp'], "%Y-%m-%dT%H:%M:%S.%f%z").timestamp())
 
             values[device_id].append(elements['value'])
         result = [(host, timestamps[host], values[host]) for host in host_list]
